@@ -90,6 +90,8 @@ _ecf_document_types = (
     '43',  # minor expenses invoices (purchases)
     '44',  # invoices for special customers (tourists, free zones)
     '45',  # invoices for the government
+    '46',  # invoices for exports
+    '47',  # invoices for foreign payments
 )
 
 
@@ -140,15 +142,15 @@ def _convert_result(result):  # pragma: no cover
         'Estado': 'status',
         'Tipo de comprobante': 'type',
         u'Válido hasta': 'valid_until',
-        'Rnc Emisor': 'rnc',
-        'Rnc Comprador': 'buyer rnc',
-        'e-NCF': 'e-NCF',
-        u'Código de Seguridad': 'security code',
-        'status': 'state',
-        'Monto Total': 'total amount',
-        'Total de ITBIS': 'total ITBIS',
-        u'Fecha Emisión': 'issuance date',
-        'Fecha de Firma': 'sign date',
+        u'Código de Seguridad': 'security_code',
+        'Rnc Emisor': 'issuing_rnc',
+        'Rnc Comprador': 'buyer_rnc',
+        'Monto Total': 'total',
+        'Total de ITBIS': 'total_itbis',
+        'Fecha Emisi&oacuten': 'issuing_date',
+        u'Fecha Emisión': 'issuing_date',
+        u'Fecha de Firma': 'signature_date',
+        'e-NCF': 'encf'
     }
     return dict(
         (translation.get(key, key), value)
@@ -163,8 +165,8 @@ def check_dgii(rnc, ncf, buyer_rnc=None, security_code=None, timeout=30):  # pra
     whether the combination of RNC and NCF is valid. The timeout is in
     seconds.
 
-    Returns a dict with the following structure:
-    * For a NCF
+    Returns a dict with the following structure::
+        For a NCF
         {
             'name': 'The registered name',
             'status': 'VIGENTE',
@@ -173,17 +175,17 @@ def check_dgii(rnc, ncf, buyer_rnc=None, security_code=None, timeout=30):  # pra
             'ncf': 'A020010210100000005',
             'validation_message': 'El NCF digitado es válido.',
         }
-    * For an ECNF
+        For an ECNF
         {
-            'Rnc Emisor': '1234567890123',
-            'Rnc Comprador': '123456789',
-            'e-NCF': 'E300000000000',
-            'Código de Seguridad': '1+2kP3',
+            'rnc_issuing': '1234567890123',
+            'rnc_buyer': '123456789',
+            'encf': 'E300000000000',
+            'security_code': '1+2kP3',
             'status': 'Aceptado',
-            'Monto Total': '2203.50',
-            'Total de ITBIS': '305.10',
-            'Fecha Emisión': '2020-03-25',
-            'Fecha de Firma': '2020-03-22',
+            'total': '2203.50',
+            'total_itbis': '305.10',
+            'issuing_date': '2020-03-25',
+            'signature_date': '2020-03-22',
             'validation_message': 'Aceptado',
         }
 
@@ -220,12 +222,12 @@ def check_dgii(rnc, ncf, buyer_rnc=None, security_code=None, timeout=30):  # pra
     # Do the actual request
     document = lxml.html.fromstring(
         session.post(url, data=data, timeout=timeout).text)
-    resultPath = './/div[@id="cphMain_PResultadoFE"]' if ncf[0] == 'E' else './/div[@id="cphMain_pResultado"]'
-    result = document.find(resultPath)
+    result_path = './/div[@id="cphMain_PResultadoFE"]' if ncf[0] == 'E' else './/div[@id="cphMain_pResultado"]'
+    result = document.find(result_path)
     if result is not None:
-        lblPath = './/*[@id="cphMain_lblEstadoFe"]' if ncf[0] == 'E' else './/*[@id="cphMain_lblInformacion"]'
+        lbl_path = './/*[@id="cphMain_lblEstadoFe"]' if ncf[0] == 'E' else './/*[@id="cphMain_lblInformacion"]'
         data = {
-            'validation_message': document.findtext(lblPath).strip(),
+            'validation_message': document.findtext(lbl_path).strip(),
         }
         data.update(zip(
             [x.text.strip() for x in result.findall('.//th') if x.text],
